pub(crate) trait ToFFI {
type Str<'a>: AsRawFFI + 'a
where Self: 'a;
// Required method
fn ffi<'a>(&'a self) -> Self::Str<'a>;
}Expand description
Trait for types that can be converted to FFI string representation.
This trait enables conversion of Rust types into string representations suitable for passing to C functions via FFI. The string type is parameterized to allow for both borrowed and owned string representations depending on the source data.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.