pub(crate) trait AsRawFFI {
type FFI;
// Required method
unsafe fn raw_ffi(&self) -> Self::FFI;
}Expand description
Trait for types that can provide a raw FFI representation.
This trait is used to convert Rust types into their corresponding C FFI types for passing across the FFI boundary.
Safety
Users must ensure that the returned FFI value is never used past the duration of the original value’s lifetime